
/**
 * An action that repeatedly inserts a message into a queue.
 */
public class Producer implements Runnable 
{
    private String text;
    private BoundedQueue queue;
    private int index;
    private int count;
    private static final int DELAY = 10;
    
    /**
     * Constructs the producer object.
     * @param aText the message text to insert into a queue
     * @param aQueue the queue into which to insert messages
     * @param aCount the number of messages to produce
     */
    public Producer(String aText, BoundedQueue aQueue, 
                    int aIndex, int aCount) 
    {
        text  = aText;
        queue = aQueue;
        index = aIndex;
        count = aCount;
    }

    public void run() 
    {
        try {
            int i = 1;
            
            while (i <= count) {
                if (!queue.isFull()) {
                    Message msg = new Message(index, i, text);
                    queue.add(msg);
                    System.out.printf("%2d P %s\n", queue.getSize(), msg);
                    i++;
                }
                
                Thread.sleep((int) (DELAY*Math.random()));
            }
        } 
        catch (InterruptedException ex) {}
    }
}
